# ortho_modificator


[![image](https://img.shields.io/pypi/v/ortho_modificator.svg)](https://pypi.python.org/pypi/ortho_modificator)
[![image](https://img.shields.io/conda/vn/conda-forge/ortho_modificator.svg)](https://anaconda.org/conda-forge/ortho_modificator)


**A python package for Orthophoto analysis and modification.**


-   Free software: MIT License
-   Documentation: https://gismam.github.io/ortho_modificator


## Features

-   Create interactive maps with minimal lines of code
-   Great tool for GIS
-   hello world